#!/bin/sh
# $Header: /CVSROOT/ptybuffer/nwn/autostart.sh,v 1.2 2004/06/03 02:49:18 tino Exp $
#
# Example autostarting script for cron for use with NWNadm and ptybuffer.
# Copyright (C)2004 by Valentin Hilbig, webmaster@20k.de
#
# In crontab enter something like next line:
# -* * * * *      $HOME/bin/autostart.sh >> $HOME/log/autostart.log 2>&1
# This tests each minute if your server is running and starts it up.
#
# Then create the autostart directory.
# In this directory softlink the startup scripts for your NWN server(s).
# The sockets will be named after these autostart scripts.
# Note that these scripts can do anything, not only starting the NWN server.
# For example you can fork a shell by an autostart script like this:
# #!/bin/bash
# exec /bin/bash
# For a miniature chat example for autostart see script chat.sh
#
# Note that this script shall be looping, such that if you server crashes
# it's restarted immediately.  This way you can see the last things
# before the crash without looking into the log files.
# If the looping script hangs, you can always kill it using the ^C
# send feature (named "terminate service" or "kill") of NWNadm.
#
# This script here needs $HOME/bin/accept,
# see http://www.scylla-charybdis.com/download/
# accept is used to check if the socket is open.
# DON'T CONFUSE accept WITH THE LPR accept/reject COMMANDS!
# (Probably I should rename it to "tino_accept" or so,
# however I never installed those, as this was inherently insecure.)
#
# $Log: autostart.sh,v $
# Revision 1.2  2004/06/03 02:49:18  tino
# updated
#
# Revision 1.1  2004/05/23 09:35:34  tino
# added
 
# CONFIG BEGIN
# I access this directory here as:
# https://the.host.name/~user/admin/
#
# Where is the server and the autostart directory?
SERVERPATH="$HOME/public_html/admin/server"
AUTOSTARTS="$HOME/autostart"
# CONFIG END

cd "$HOME" || exit

date

export PATH="$HOME/bin:$PATH"

for file in "$AUTOSTARTS"/*
do
	what="`basename "$file"`"
	[ -f "$file" ] || continue
	[ -x "$file" ] || continue
	case "$what" in
	*~ | *\# | \#*)	continue;;
	esac

	SOCK="$SERVERPATH/$what"
	if [ -e "$SOCK" ]
	then
 		if [ ! -S "$SOCK" ]
		then
			echo "$what: nonsocket $SOCK" >&2
			exit 1
		fi
		if accept ">$SOCK" >/dev/null 2>&1 <&1
		then
			echo "running:  $what"
			continue
		fi
		rm -f "$SOCK"
	fi

	echo "starting: $what"
	ptybuffer "$SOCK" "$file" "$what"
done
exit 0
